﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace DisplayASimpleMapForMvc.Controllers
{
    public class HomeController : Controller
    {
        //
        // GET: /Home/

        public ActionResult Index()
        {
            Map map = new Map("Map1",
                    new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                    510);
            map.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            map.CurrentExtent = new RectangleShape(-125, 72, 50, -46);
            map.MapUnit = GeographyUnit.DecimalDegree;

            WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay("WorldMapKitOverlay");
            map.CustomOverlays.Add(worldMapKitOverlay);
            SetupAVLOverlay(map);

            return View(map);
        }

        protected void SetupAVLOverlay(Map Map)
        {
            //Setup the FeatureSourceColumns.
            List<FeatureSourceColumn> columns = new List<FeatureSourceColumn>();

            //Base AVL Info
            columns.Add(new FeatureSourceColumn("Id"));
            columns.Add(new FeatureSourceColumn("isLate"));

            //Create the FeatureSourceMarkerOverlay.
            InMemoryMarkerOverlay avlDataOverlay = new InMemoryMarkerOverlay("AVLOverlay", columns);

            //Create the ClassBreakMarkerStyle.
            ClassBreakMarkerStyle cbms = new ClassBreakMarkerStyle("isLate", BreakValueInclusion.IncludeValue);

            //Add MarkerClassBreak objects, they need to be added from smallest value to largest largest value.

            //Create the first MarkerClassBreak object, set it up, and add it to the collection.
            MarkerClassBreak onTime = new MarkerClassBreak();
            onTime.Value = 0;
            //Use the custom MarkerStyle for ontime.
            onTime.DefaultMarkerStyle.WebImage = new WebImage(@"/Content/theme/default/img/marker_blue.gif");

            cbms.ClassBreaks.Add(onTime);

            //Create the MarkerClassBreak object, set it up, and add it to the collection.
            MarkerClassBreak late = new MarkerClassBreak();
            late.Value = 1;
            //Use the custom MarkerStyle for late.
            late.DefaultMarkerStyle.WebImage = new WebImage(@"/Content/theme/default/img/marker.gif");

            cbms.ClassBreaks.Add(late);

            avlDataOverlay.ZoomLevelSet.ZoomLevel01.CustomMarkerStyle = cbms;
            avlDataOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            //Set the visibility and whether the overlay is visible in the overlay switcher.
            avlDataOverlay.IsVisible = true;

            avlDataOverlay.IsVisibleInOverlaySwitcher = false;

            //Add the overlay to the map.
            Map.CustomOverlays.Add(avlDataOverlay);
        }

        [MapActionFilter]
        public void ClickEvent(Map map, GeoCollection<object> args)
        {
            PointShape position = new PointShape(Convert.ToDouble(args[0]), Convert.ToDouble(args[1]));
            InMemoryMarkerOverlay markerOverlay = (InMemoryMarkerOverlay)map.CustomOverlays["AVLOverlay"];

            Feature newFeature = new Feature(position);
            newFeature.ColumnValues.Add("Id", Guid.NewGuid().ToString());
            newFeature.ColumnValues.Add("isLate", new Random().Next(2).ToString());
            markerOverlay.FeatureSource.InternalFeatures.Add("marker" + Guid.NewGuid().ToString(), newFeature);
        }

    }
}
